;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xb075aaf79d16fe553eeb2b2b1f09758a . "./code.cg2js/cg-status-bar.fasl")
(#x2f7026bd6b11d383cbf874dc4872b8c0 . "./code.cg2js/cg-hotspot.fasl")
(#xe58c893c2706d51ef9044749b26494b5 . "./code.cg2js/cg-toolbar.fasl")
(#x465058157ee50c2a663f3bb0e65d1543 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x0f3909229a64f16159e288bbfd02aab3 . "./code.cg2js/cg-tooltip.fasl")
(#xe8caa9b3ea1cb06d8ced31d4e1237e25 . "./code.cg2js/cg-calendar.fasl")
(#x1aaee1e349524956d92735cdccf21ef0 . "./code.cg2js/cg-item-list.fasl")
(#x46ff2adcf47316d5a82721936b99e565 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xc1353d6033d09747d919a9d0793a324d . "./code.cg2js/cg-trackbar.fasl")
(#x3a7152b9565d1453fb6bb9067e756799 . "./code.cg2js/cg-class-grid.fasl")
(#x5465db431e81a3014efad2337606d860 . "./code.cg2js/cg-dialog-item.fasl")
(#x9b58814165c88c14018fff94c36e4be6 . "./code.cg2js/cg-comtab.fasl")
(#x00cba9c88e5debc0ee1d6cb9bb2acc71 . "./code.cg2js/cg-lisp-text.fasl")
(#x253fc56f0189b935b64942a09839da21 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xf868af7a3241fc3fda89267b56a1d061 . "./code.cg2js/cg-button.fasl")
(#x27e840b054398222d2d320c2f1827ed1 . "./code.cg2js/cg-printing.fasl")
(#x7c46d970cb5fa82c6f6ef1da093340e3 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xb3383642379ed0c99d1710cef1101d70 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xe1cc36b758104c3387bd6946e6a8161b . "./code.cg2js/cg-pixmap-widget.fasl")
(#x4ba3cf8c211d43de07628804e0a85416 . "./code.cg2js/cg-selected-object.fasl")
(#xdd6437fa02a66171ef6b755db8d58ca1 . "./code.cg2js/cg-text-or-combo.fasl")
(#x350ed9e0274363ef41d27a4371190edb . "./code.cg2js/cg-graphics-context.fasl")
(#x547e0e72b0b5e787ed5f4b708b876e48 . "./code.cg2js/cg-edit-in-place.fasl")
(#x9e7ed103a4ef68810141b27c5ea4aede . "./code.cg2js/cg-string-dialog.fasl")
(#x16c75765b61946f97fe3d2d8a243a3f2 . "./code.cg2js/cg-list-view.fasl")
(#xeabf3d9ea8f89737a72f1c0e0dbdbd42 . "./code.cg2js/cg-intersect.fasl")
(#xb8a544ae23cc7ab1d53b4ac2f1d16ada . "./code.cg2js/cg-text-widget.fasl")
(#x0fa6d04244c30ecee7f1f96118e0076f . "./code.cg2js/cg-directory-dialog.fasl")
(#xad82f7fd52224e4e3b6a1dcee5e439ec . "./code.cg2js/cg-file-dialog.fasl")
(#x15dbb8e457c6638c019e6aa595ef273a . "./code.cg2js/cg-dde-utils.fasl")
(#x4757f854ff575294e6d7339e9f8b1b43 . "./code.cg2js/cg-nodes.fasl")
(#xc3010c04fbdbf8833810ed5bfd5e28c3 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x1c707f8fb37b331da4b46b9f229ddfac . "./code.cg2js/cg-up-down-control.fasl")
(#x23e78fad81a7255b21a9449c3fb36eb4 . "./code.cg2js/cg-get-position.fasl")
(#xa8c871392a34748b7563fdf04851870e . "./code.cg2js/cg-toggling-widget.fasl")
(#x4d57044d064164e974af8042ac31edfd . "./code.cg2js/cg-acache.fasl")
(#x27cc8798114f1682ac9028efe7ae8612 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x06285ad5511be12ec09e5d5031f599fd . "./code.cg2js/cg-base.fasl")
(#x09a575537afca14f39be274f91196160 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x5cd1be6c9255604e05d78051216b909a . "./code.cg2js/cg-find-string-dialog.fasl")
(#xf65d4284b6f1b219a533d969fb9eed29 . "./code.cg2js/cg-property.fasl")
(#x9acffae18fc886cc3afff07f85e4cf5a . "./code.cg2js/cg-editable-text.fasl")
(#xe3467c2a88a8ebb1534f00c163ea00ac . "./code.cg2js/cg-lamp.fasl")
(#x63402d98354c41519ab702a21dcfd8e3 . "./code.cg2js/cg-progress-indicator.fasl")
(#xf8505b649b6f338b58ee96e00ee8c8ae . "./code.cg2js/cg-chart-widget.fasl")
(#x3d10247402c8dc4831814e0c67f9a82d . "./code.cg2js/cg-common-control.fasl")
(#xab7e97c0391afd9904c8aeefb5d8138e . "./code.cg2js/cg-font-dialog.fasl")
(#x44c0d2fdb10333ae3bc793e02df1ef8c . "./code.cg2js/cg-gesture-emulation.fasl")
(#x28172c022ed65453d7ceb140fea22f4c . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x83527a46f608dab426c2cfa1c4bb515f . "./code.cg2js/cg-os-window.fasl")
(#xeb256aa8f6ee78d36dd8b31c68e81670 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x8337946e07e07407ff9843997502fedd . "./code.cg2js/cg-pixmap.fasl")
(#x2f28ed9c3f4e7e3448a4382a38be5300 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x0ab2d86121a889c2898b0773f6452fa7 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x0ff192ba63cb7ccf6517e15d1b794619 . "./code.cg2js/cg-scaling-stream.fasl")
(#x18d4a768919996d3efee63835746a2ba . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x068d66d6edac742047d3dcc94d9c691f . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xbf77a15dea909cab384b647bcad076a9 . "./code.cg2js/cg-timer.fasl")
(#x5e2f5ccfd6a43e66256664b8e8c6a08c . "./code.cg2js/cg-scroll-bar.fasl")
(#xa3f3bd5a7b34c5675027144cc811442a . "./code.cg2js/cg-caret.fasl")
(#x94c1f6c19f43d1844ac4e43478e82eda . "./code.cg2js/cg-template-string.fasl")
(#x05f162fe9126e7ca4ee8fea26d55fe17 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xf26a8120aea37f504146d4acc7cbe22e . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x5627c09d9e50ba860b8f8d56db8602c0 . "./code.cg2js/cg-rich-edit.fasl")
(#xd061af89ab6b684590d29b476cfb6c32 . "./code.cg2js/cg-combo-box.fasl")
(#x89d7cb6e1b386046801cc770ef119f04 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x5abcc43874c02a4bb98f911bb6efad93 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x9543f81e8e9d30a65b99231695af578b . "./code.cg2js/cg-menu-tooltip.fasl")
(#x641d7280d996caec11cc0136ab9f5212 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xa0ca8165d1ec58ea6645c6e03e812f9c . "./code.cg2js/cg-outline.fasl")
(#x8c30fa778c114f90be91636fd964ef54 . "./code.cg2js/cg-class-support.fasl")
(#x71697c78e68afdd53a3c8aa341b26954 . "./code.cg2js/cg-header-control.fasl")
(#xebda13bd5ae8f560afeead2aefa621e5 . "./code.cg2js/cg-lettered-menu.fasl")
(#xaee4abc919eeb0c40b288e8b60290d0b . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xca624a37960bc60dcddffde9dcbf2fa9 . "./code.cg2js/cg-fill-texture.fasl")
(#x68920587926c2cd5c2cd7fb027d24ecf . "./code.cg2js/cg-lisp-widget.fasl")
(#x1c595af6d396d360f0167e2a6afef87b . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x84d33f9d1a428ba99f5fef0a0ab0726d . "./code.cg2js/cg-clipboard.fasl")
(#xf99b5c81142307fb7c43895dd5283015 . "./code.cg2js/cg-wrap-string.fasl")
(#x192ce85f4f123b38e5e5588508b0367b . "./code.cg2js/cg-os-widget.fasl")
(#x1f2374600bcd53d61bcf7d06545ac41c . "./code.cg2js/cg-check-box.fasl")
(#x6c99ce462b3fac23ad99940c71d3c0f9 . "./code.cg2js/cg-choice-list.fasl")
(#x75b5a436e5bd31a3a65fb350015e5cbf . "./code.cg2js/cg-layout.fasl")
(#x1e7ed098b288c110e904e59102113358 . "./code.cg2js/cg-group-box.fasl")
(#xd2df813ff6e20241c7df2d49b7781180 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xd4235fda5a3c625ef1847ec72e5f83fd . "./code.cg2js/cg-radio-button.fasl")
(#xdeebea09efc615cb19149480593440e8 . "./code.cg2js/cg-tab-control.fasl")
(#xcf028b984529c51feb2666080773cd22 . "./code.cg2js/cg.fasl")
(#xe11218613be8ac80fc3c48db50863f97 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x3520884b188f7bf2284d97f4c29d7934 . "./code.cg2js/cg-dropping-outline.fasl")
(#xd95fe4488d39ea34c39c3a22d7c0cb4c . "./code.cg2js/cg-get-pixmap.fasl")
(#xe95ee70bb3372b7667225e573447beba . "./code.cg2js/cg-grid-widget.fasl")
(#xb581f09813acc427d265727b84022bf8 . "./code.cg2js/cg-utility-dialog.fasl")
(#xff6b4db595539716d2cc7f89cf30d66c . "./code.cg2js/cg-static-text.fasl")
(#xda441f6bc4395bde96725aaccda5c4bc . "./code.cg2js/cg-class-slot-grid.fasl")
(#xb8c28fa38da3a2d5287637dad939cb00 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x18c2b2c5229c2fc37b8d6104d99eebca . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x5e1c0b7e716b0085ad704648273768bb . "./code.cg2js/cg-bitmap-pane.fasl")
(#xfe38da1679f32fab58958c7c1d1246f8 . "./code.cg2js/cg-plot-widget.fasl")
(#xeeab501338bc05cc46a570c374424e7d . "./code.cg2js/cg-color-dialog.fasl")
(#x5d25a141ee880974d65d13bf0370d62e . "./code.cg2js/cg-icon-pixmap.fasl")
(#xac43ea073ecf3c7623a4b5a6f4be0301 . "./code.cg2js/cg-icon.fasl")
(#x1723750c8b664e4d469d541a9c6513e9 . "./code.cg2js/cg-dev.fasl")
(#x0813a678029b4af05c56d78d1c6e34a5 . "./code.cg2js/cg-choose-printer.fasl")
(#x670d6c85ccc1c7bcdd17f372cba9655a . "./code.cg2js/cg-intersect-posbox.fasl")
(#xa61a57d49d3cf21347ccb717a265fc4a . "./code.cg2js/cg-menu.fasl")
(#xf230ab44223f3b70b32e2fe6f582d551 . "./code.cg2js/cg-yes-no-list.fasl")
(#x395005a348558bf19d515ef8faef2344 . "./code.cg2js/cg-palette.fasl")
(#x075e800d6e6e4b4e33586ffd0748060e . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x4d13fb9c0db3a4c319da5961577f37af . "./code.cg2js/cg-message-dialog.fasl")
(#xc21f5940e3294eda0ecb124e53105b36 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x5fe5292ed7a5e7fbe0eb15faa8a8755d . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x1aed2ba0ccab2cf74433fbca5125c3f6 . "./code.cg2js/cg-split-bar.fasl")
(#x06e6e63a7e8e3ce95e678ca332ded748 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x37af6577cbc11e255691dc3e3e34cc75 . "./code.cg2js/cg-web-browser.fasl")
(#x77b285b96092a1ea898233cbeed167f1 . "./code.cg2js/cg-project-window.fasl")
(#xe4f01bf7faef28490450a16b6dccc960 . "./code.cg2js/cg-picture-widget.fasl")
(#x0bdde2bfc9f39e0a8c659de4d8829431 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xb6abd50d15e79c7b41b13407c9886b97 . "./code.cg2js/cg-object-editor.fasl")
(#xc9a59b4f1eb7c706a417ce6b1194569e . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xef5d79a201aec01c7797655da33452ba . "./code.cg2js/cg-paren-matching.fasl")
(#xbdce424a91dc39819856873722ba3296 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x4b392989461ebafd03164ff2e6fa499e . "./code.cg2js/cg-drawable.fasl")
(#xdb8244a0fbbe8ac83f76f9c884f1ca51 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xa8a85a49e5ceb6cecbc008d0fd4bab8c . "./code.cg2js/cg-html-widget.fasl")
(#x92e79241000582c27418019e1e9e6b6c . "./code.cg2js/cg-curve.fasl")
(#x4f2f355aff81bcf16f260e3173ea5163 . "./code.cg2js/cg-yes-no-string.fasl")
(#xad24ebaadc1174fa2d39d5b23a004fd3 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x91d4dcd4c8a9c3408a638f12edbd0136 . "./code.cg2js/cg-html-dialog.fasl")
(#xbd7ae2c0f37fda5519f9388ddccdce0b . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x8f38c313f16c473f18916796b64bd35b . "./code.cg2js/cg-tray.fasl")
(#x86c2476a281a1fa8fa5d3cc38ba75a8d . "./code.idejs/ide-apropos.fasl")
(#x723518f132de4cbd36a6f25d79003e3c . "./code.idejs/ide-window-list.fasl")
(#x169885d6c502170fe6b39cb20da1b200 . "./code.idejs/ide-class-browser.fasl")
(#x18d43e45429b9790773f5878046ca2a6 . "./code.idejs/ide-base.fasl")
(#x858c966a6bdcfec3d8d271e82a456743 . "./code.idejs/ide-process-browser.fasl")
(#x2a8aaabeb8aafed93bdb2b2a35bd6d37 . "./code.idejs/ide-acache.fasl")
(#xd911b79d0ac6b9ac1999aa6890d04c60 . "./code.idejs/ide-navigator.fasl")
(#x7a3e215bf87e34f73147e39f6d3d6be9 . "./code.idejs/ide-trace.fasl")
(#x4719bdf416a052823f686c4d59022974 . "./code.idejs/ide-project.fasl")
(#xc088876f04c217e9699e10dab42a0129 . "./code.idejs/ide-patch-dialog.fasl")
(#x9aa66e0c79027ba9e165f1d11ee0d641 . "./code.idejs/ide-grapher.fasl")
(#x167427907a3196f9953abbc61f7162d3 . "./code.idejs/ide-dev.fasl")
(#x6896b6799e7b40ebceeef3ff4d5ce67b . "./code.idejs/ide-keyshort.fasl")
(#x5370be03e0e1781030496a72f7db1734 . "./code.idejs/ide-editor.fasl")
(#xd48d6ff8ceddc53f7e2e81261e7d45e7 . "./code.idejs/ide-inspector.fasl")
(#x60302bffc92d6f273e2bd76ff8aac591 . "./code.idejs/ide.fasl")
(#x1882e767f7b2e2f692c91263fceda5ed . "./code.idejs/ide-clipboard.fasl")
(#xf52e7378c3b3d85c206e614df09be1dc . "./code.idejs/ide-find-definitions.fasl")
(#xee98f6aa9acba8b278f29a5657e5a2f6 . "./code.idejs/ide-form.fasl")
(#x9c8d4e500332df7bd2147c350d755851 . "./code.idejs/ide-intro.fasl")
(#x81c834326a8955d76ad30c84e7ac7c9f . "./code.idejs/ide-find-in-files.fasl")
(#xa3f4d6ecf9b0e5c9a5a874c4820d9c05 . "./code.idejs/ide-package-list.fasl")
(#x95114d43212c2562456ed85535a54f3b . "./code.idejs/ide-class-grapher.fasl")
(#xb19a66ec109be5a69fb5293c577fc104 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
